@@ -22,7 +22,7 @@ Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Resets internal variables.
 sub reset {
@@ -746,15 +746,33 @@ L<Tags::Utils::Preserve>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::ESIS>,
-L<Tags::Output::Indent2>,
-L<Tags::Output::LibXML>,
-L<Tags::Output::PYX>,
-L<Tags::Output::Raw>,
-L<Tags::Output::SESIS>,
-L<Tags::Utils>.
+=over
+
+=item L<Tags>
+
+Structure oriented SGML/XML/HTML/etc. elements manipulation.
+
+=item L<Tags::Output>
+
+Base class for Tags::Output::*.
+
+=item L<Tags::Output::LibXML>
+
+Printing 'Tags' structure by LibXML library.
+
+=item L<Tags::Output::PYX>
+
+PYX class for line oriented output for 'Tags'.
+
+=item L<Tags::Output::Raw>
+
+Raw printing 'Tags' structure to tags code.
+
+=item L<Tags::Utils>
+
+Utils module for Tags.
+
+=back
 
 =head1 AUTHOR
 
@@ -762,10 +780,11 @@ Michal Špaček L<skim@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2011-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
